package com.qmth.eds.api;

import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.eds.common.contant.SystemConstant;
import com.qmth.eds.common.entity.SysUser;
import com.qmth.eds.common.util.Result;
import com.qmth.eds.common.util.ResultUtil;
import com.qmth.eds.service.SysUserService;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

/**
 * <p>
 * 用户表 前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2022-05-14
 */
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/sys_user")
public class SysUserController {

    @Resource
    private SysUserService sysUserService;

    /**
     * 查询
     *
     * @param loginName  用户名
     * @param realName   姓名
     * @param enable     状态
     * @param pageNumber 分页参数
     * @param pageSize   分页参数
     */
    @ApiOperation(value = "查询")
    @PostMapping("/page")
    public Result page(@RequestParam(value = "loginName", required = false) String loginName,
                       @RequestParam(value = "realName", required = false) String realName,
                       @RequestParam(value = "enable", required = false) Boolean enable,
                       @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                       @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(sysUserService.list(loginName, enable, realName, pageNumber, pageSize));
    }

    /**
     * 新增/修改
     *
     * @param sysUser 用户对象
     */
    @ApiOperation(value = "新增/修改")
    @PostMapping("/save")
    public Result save(@ApiParam(value = "用户信息", required = true) @Valid @RequestBody SysUser sysUser, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(sysUserService.saveUser(sysUser));
    }

    /**
     * 启用/禁用
     *
     * @param sysUser 用户对象
     */
    @ApiOperation(value = "启用/禁用")
    @PostMapping("/enable")
    public Result enable(@RequestBody SysUser sysUser) {
        return ResultUtil.ok(sysUserService.enable(sysUser));
    }

    /**
     * 删除
     *
     * @param id 用户id
     */
    @ApiOperation(value = "删除")
    @PostMapping("/delete")
    public Result delete(@RequestParam Long id) {
        return ResultUtil.ok(sysUserService.delete(id));
    }

    /**
     * 重置密码
     *
     * @param sysUser 用户对象
     */
    @ApiOperation(value = "重置密码")
    @PostMapping("/reset_password")
    public Result resetPassword(@RequestBody SysUser sysUser) {
        return ResultUtil.ok(sysUserService.resetPassword(sysUser.getId()));
    }
}
